@@ -360,6 +360,11 @@ gst_net_client_internal_clock_observe_times (GstNetClientInternalClock * self,
   GST_OBJECT_LOCK (self);
   rtt_limit = self->roundtrip_limit;
 
+  GST_LOG_OBJECT (self,
+      "local1 %" G_GUINT64_FORMAT " remote1 %" G_GUINT64_FORMAT " remote2 %"
+      G_GUINT64_FORMAT " local2 %" G_GUINT64_FORMAT, local_1, remote_1,
+      remote_2, local_2);
+
   /* If the server told us a poll interval and it's bigger than the
    * one configured via the property, use the server's */
   if (self->last_remote_poll_interval != GST_CLOCK_TIME_NONE &&
@@ -477,10 +482,8 @@ gst_net_client_internal_clock_observe_times (GstNetClientInternalClock * self,
   remote_avg = (remote_2 + remote_1) / 2;
 
   GST_LOG_OBJECT (self,
-      "local1 %" G_GUINT64_FORMAT " remote1 %" G_GUINT64_FORMAT " remote2 %"
-      G_GUINT64_FORMAT " remoteavg %" G_GUINT64_FORMAT " localavg %"
-      G_GUINT64_FORMAT " local2 %" G_GUINT64_FORMAT, local_1, remote_1,
-      remote_2, remote_avg, local_avg, local_2);
+      "remoteavg %" G_GUINT64_FORMAT " localavg %" G_GUINT64_FORMAT,
+      remote_avg, local_avg);
 
   clock = GST_CLOCK_CAST (self);
 
@@ -957,7 +960,7 @@ struct _GstNetClientClockPrivate
   GstClockTime roundtrip_limit;
   GstClockTime minimum_update_interval;
 
-  GstClockTime base_time;
+  GstClockTime base_time, internal_base_time;
 
   gchar *address;
   gint port;
@@ -1055,6 +1058,7 @@ static void
 gst_net_client_clock_init (GstNetClientClock * self)
 {
   GstNetClientClockPrivate *priv;
+  GstClock *clock;
 
   self->priv = priv = GST_NET_CLIENT_CLOCK_GET_PRIVATE (self);
 
@@ -1066,7 +1070,11 @@ gst_net_client_clock_init (GstNetClientClock * self)
 
   priv->roundtrip_limit = DEFAULT_ROUNDTRIP_LIMIT;
   priv->minimum_update_interval = DEFAULT_MINIMUM_UPDATE_INTERVAL;
+
+  clock = gst_system_clock_obtain ();
   priv->base_time = DEFAULT_BASE_TIME;
+  priv->internal_base_time = gst_clock_get_time (clock);
+  gst_object_unref (clock);
 }
 
 /* Must be called with clocks_lock */
@@ -1210,9 +1218,15 @@ gst_net_client_clock_set_property (GObject * object, guint prop_id,
       GST_OBJECT_UNLOCK (self);
       update = TRUE;
       break;
-    case PROP_BASE_TIME:
+    case PROP_BASE_TIME:{
+      GstClock *clock;
+
       self->priv->base_time = g_value_get_uint64 (value);
+      clock = gst_system_clock_obtain ();
+      self->priv->internal_base_time = gst_clock_get_time (clock);
+      gst_object_unref (clock);
       break;
+    }
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -1287,7 +1301,6 @@ gst_net_client_clock_constructed (GObject * object)
 {
   GstNetClientClock *self = GST_NET_CLIENT_CLOCK (object);
   GstClock *internal_clock;
-  GstClockTime internal;
   GList *l;
   ClockCache *cache = NULL;
 
@@ -1319,6 +1332,11 @@ gst_net_client_clock_constructed (GObject * object)
         self->priv->address, "port", self->priv->port, "is-ntp",
         self->priv->is_ntp, NULL);
     clocks = g_list_prepend (clocks, cache);
+
+    /* Not actually leaked but is cached for a while before being disposed,
+     * see gst_net_client_clock_finalize, so pretend it is to not confuse
+     * tests. */
+    GST_OBJECT_FLAG_SET (cache->clock, GST_OBJECT_FLAG_MAY_BE_LEAKED);
   }
 
   cache->clocks = g_list_prepend (cache->clocks, self);
@@ -1335,27 +1353,6 @@ gst_net_client_clock_constructed (GObject * object)
 
   self->priv->internal_clock = internal_clock = cache->clock;
 
-  /* gst_clock_get_time() values are guaranteed to be increasing. because no one
-   * has called get_time on this clock yet we are free to adjust to any value
-   * without worrying about worrying about MAX() issues with the clock's
-   * internal time.
-   */
-
-  /* update our internal time so get_time() give something around base_time.
-     assume that the rate is 1 in the beginning. */
-  internal = gst_clock_get_internal_time (internal_clock);
-  gst_clock_set_calibration (internal_clock, internal,
-      self->priv->base_time, 1, 1);
-
-  {
-    GstClockTime now = gst_clock_get_time (internal_clock);
-
-    if (GST_CLOCK_DIFF (now, self->priv->base_time) > 0 ||
-        GST_CLOCK_DIFF (now, self->priv->base_time + GST_SECOND) < 0) {
-      g_warning ("unable to set the base time, expect sync problems!");
-    }
-  }
-
   /* all systems go, cap'n */
 }
 
@@ -1364,6 +1361,12 @@ gst_net_client_clock_get_internal_time (GstClock * clock)
 {
   GstNetClientClock *self = GST_NET_CLIENT_CLOCK (clock);
 
+  if (!gst_clock_is_synced (self->priv->internal_clock)) {
+    GstClockTime now = gst_clock_get_internal_time (self->priv->internal_clock);
+    return gst_clock_adjust_with_calibration (self->priv->internal_clock, now,
+        self->priv->internal_base_time, self->priv->base_time, 1, 1);
+  }
+
   return gst_clock_get_time (self->priv->internal_clock);
 }
 
